@@ -6,19 +6,19 @@ from .train import train_generate
 from .process import preprocess_generate
 from .metrics import log_metrics
 
-from .train.templates import logistic_regression
+from .train.templates import temp_logistic_regression
 
 
 def generate_file(url,graph,colab=False):
 
     preprocess_template = preprocess_generate(graph)
-    train_template = logistic_regression()
+    train_template = temp_logistic_regression()
     #output_template = preprocess_template + train_template
     if colab:
         with open("/content/output.py", "w") as f:
             f.write("import huble\n")
             f.write("from sklearn.model_selection import train_test_split\n")
-            f.write(f"data=huble.util.load_dataset("{url}")")
+            f.write(f"data=huble.util.load_dataset(\"{url}\")")
             f.write(preprocess_template)
             f.write("\nX = data.drop(columns = ['PClass'],axis = 1)\n")
             f.write("y = data['PClass']\n")
