@@ -71,7 +71,10 @@ def temp_drop_rows_columns(params):
     return f"data = huble.sklearn.drop_rows_columns(data=data,parameters={parameters})"
 
 def temp_remove_outliers(params):
-    return f"data = huble.sklearn.remove_outliers(data=data,columns='{params['columns']}')"
+    columns=[]
+    for i in range(len(params['columns'])):
+        columns.append(params['columns'][i]['value'])
+    return f"data = huble.sklearn.remove_outliers(data=data,columns={columns})"
 
 def temp_drop_duplicates(params):
     subset=[]
